@@ -220,6 +220,7 @@ class Acquisition(object):
         directory=None,
         name=None,
         image_process_fn=None,
+        event_generation_hook_fn=None,
         pre_hardware_hook_fn=None,
         post_hardware_hook_fn=None,
         post_camera_hook_fn=None,
@@ -248,6 +249,11 @@ class Acquisition(object):
             object for the purposes of interacting with arbitrary code on the Java side (such as the micro-manager
             core), and queue is a Queue objects that holds upcomning acquisition events. Both version must either
             return
+        event_generation_hook_fn : Callable
+            hook function that will as soon as acquisition events are generated (before hardware sequencing optimization
+            in the acquisition engine. This is useful if one wants to modify acquisition events that they didn't generate
+            (e.g. those generated by a GUI application). Accepts either one argument (the current acquisition event)
+            or three arguments (current event, bridge, event Queue)
         pre_hardware_hook_fn : Callable
             hook function that will be run just before the hardware is updated before acquiring
             a new image. In the case of hardware sequencing, it will be run just before a sequence of instructions are
@@ -347,6 +353,12 @@ class Acquisition(object):
             self._remote_acq.add_image_processor(processor)
             self._start_processor(processor, image_process_fn, self._event_queue, process=process)
 
+        if event_generation_hook_fn is not None:
+            hook = self.bridge.construct_java_object(
+                "org.micromanager.remote.RemoteAcqHook", args=[self._remote_acq]
+            )
+            self._start_hook(hook, event_generation_hook_fn, self._event_queue, process=process)
+            self._remote_acq.add_hook(hook, self._remote_acq.EVENT_GENERATION_HOOK)
         if pre_hardware_hook_fn is not None:
             hook = self.bridge.construct_java_object(
                 "org.micromanager.remote.RemoteAcqHook", args=[self._remote_acq]
